@@ -19,7 +19,7 @@ def env():
 
 class raw_env(AECEnv):
 
-    metadata = {'render.modes': ['human'], "name": "chess_v2"}
+    metadata = {'render.modes': ['human'], "name": "chess_v4"}
 
     def __init__(self):
         super().__init__()
@@ -33,7 +33,7 @@ class raw_env(AECEnv):
 
         self.action_spaces = {name: spaces.Discrete(8 * 8 * 73) for name in self.agents}
         self.observation_spaces = {name: spaces.Dict({
-            'observation': spaces.Box(low=0, high=1, shape=(8, 8, 20), dtype=np.bool),
+            'observation': spaces.Box(low=0, high=1, shape=(8, 8, 111), dtype=bool),
             'action_mask': spaces.Box(low=0, high=1, shape=(4672,), dtype=np.int8)
         }) for name in self.agents}
 
@@ -43,8 +43,11 @@ class raw_env(AECEnv):
 
         self.agent_selection = None
 
+        self.board_history = np.zeros((8, 8, 104), dtype=bool)
+
     def observe(self, agent):
         observation = chess_utils.get_observation(self.board, self.possible_agents.index(agent))
+        observation = np.dstack((observation[:, :, :7], self.board_history))
         legal_moves = chess_utils.legal_moves(self.board) if agent == self.agent_selection else []
 
         action_mask = np.zeros(4672, int)
@@ -68,6 +71,8 @@ class raw_env(AECEnv):
         self.dones = {name: False for name in self.agents}
         self.infos = {name: {} for name in self.agents}
 
+        self.board_history = np.zeros((8, 8, 104), dtype=bool)
+
     def set_game_result(self, result_val):
         for i, name in enumerate(self.agents):
             self.dones[name] = True
@@ -80,6 +85,8 @@ class raw_env(AECEnv):
             return self._was_done_step(action)
         current_agent = self.agent_selection
         current_index = self.agents.index(current_agent)
+        next_board = chess_utils.get_observation(self.board, current_agent)
+        self.board_history = np.dstack((next_board[:, :, 7:], self.board_history[:, :, :-13]))
         self.agent_selection = self._agent_selector.next()
 
         chosen_move = chess_utils.action_to_move(self.board, action, current_index)
