@@ -19,13 +19,18 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {'render.modes': ['human'], "name": "dou_dizhu_v2"}
+    metadata = {'render.modes': ['human'], "name": "dou_dizhu_v4"}
 
     def __init__(self, opponents_hand_visible=False):
         self._opponents_hand_visible = opponents_hand_visible
         self.agents = ['landlord_0', 'peasant_0', 'peasant_1']
-        num_planes = 6 if self._opponents_hand_visible else 4
-        super().__init__("doudizhu", 3, (num_planes, 5, 15))
+        obs_dimension = 901 if self._opponents_hand_visible else 847
+        super().__init__("doudizhu", 3, (obs_dimension, ))
+        self.observation_spaces = self._convert_to_dict([spaces.Dict(
+            {'observation': spaces.Box(low=0.0, high=1.0, shape=(obs_dimension - 111, )
+             if agent == 'landlord_0' else (obs_dimension, ), dtype=self._dtype),
+             'action_mask': spaces.Box(low=0, high=1, shape=(self.env.num_actions,), dtype=self._dtype)})
+             for agent in self.agents])
 
     def _scale_rewards(self, reward):
         # Maps 1 to 1 and 0 to -1
@@ -36,10 +41,10 @@ class raw_env(RLCardBase):
         if self._opponents_hand_visible:
             observation = obs['obs'].astype(self._dtype)
         else:
-            observation = obs['obs'][[0, 2, 3, 4], :, :].astype(self._dtype)
+            observation = np.delete(obs['obs'], range(54, 108)).astype(self._dtype)
 
         legal_moves = self.next_legal_moves
-        action_mask = np.zeros(309, int)
+        action_mask = np.zeros(27472, int)
         for i in legal_moves:
             action_mask[i] = 1
 
