@@ -1,13 +1,13 @@
 from ._mpe_utils.simple_env import SimpleEnv, make_env
 from .scenarios.simple_adversary import Scenario
-from pettingzoo.utils.to_parallel import parallel_wrapper_fn
+from pettingzoo.utils.conversions import parallel_wrapper_fn
 
 
 class raw_env(SimpleEnv):
-    def __init__(self, N=2, max_cycles=25):
+    def __init__(self, N=2, max_cycles=25, continuous_actions=False):
         scenario = Scenario()
-        world = scenario.make_world(N=2)
-        super().__init__(scenario, world, max_cycles)
+        world = scenario.make_world(N)
+        super().__init__(scenario, world, max_cycles, continuous_actions)
         self.metadata['name'] = "simple_adversary_v2"
 
 
