@@ -1,4 +1,11 @@
+from pettingzoo.utils.conversions import to_parallel_wrapper, from_parallel_wrapper
+from pettingzoo.utils.wrappers import BaseWrapper
+
+
 def parallel_api_test(par_env, num_cycles=10):
+    assert not isinstance(par_env.unwrapped, to_parallel_wrapper)
+    assert not isinstance(par_env.unwrapped, from_parallel_wrapper)
+    assert not isinstance(par_env.unwrapped, BaseWrapper)
     MAX_RESETS = 2
     for n_resets in range(MAX_RESETS):
         obs = par_env.reset()
@@ -25,6 +32,6 @@ def parallel_api_test(par_env, num_cycles=10):
                 if d:
                     live_agents.remove(agent)
             has_finished |= {agent for agent, d in done.items() if d}
-            if par_env.env_done:
+            if not par_env.agents:
                 assert has_finished == set(par_env.possible_agents), "not all agents finished, some were skipped over"
                 break
